﻿Imports System.IO
Imports System.Runtime.Serialization
Imports System.Runtime.Serialization.Formatters.Binary

''' <summary>
''' Implementierung einer Datenbank. Die Daten werden in einer
''' <see cref="Dictionary(Of TKey, TValue)">Dictionary</see> im Speicher gehalten.
''' </summary>
''' <remarks>Die Daten werden im Binärformat persisitiert (siehe <see cref="BinaryFormatter"/>).</remarks>
Public Class BinaryDictionaryDB
   Inherits DictionaryDBBase

   ''' <summary>
   ''' Initalisiert eine neue Instanz der Datenbank.
   ''' </summary>
   ''' <param name="FileName">Der Dateipfad für die persistierten Daten.
   ''' Die Voreinstellung ist "UrsWebBinDB".</param>
   Public Sub New(Optional FileName As String = "UrsWebBinDB")
      MyBase.New(FileName)
   End Sub

   ''' <summary>
   ''' Liest Daten aus der festgelegten Datei ein.
   ''' </summary>
   ''' <returns><b>True</b>, wenn die Datei vorhanden ist.</returns>
   ''' <remarks>Siehe <see cref="DictionaryBase.New()"/> und <see cref="DBFileName"/> </remarks>
   Protected Overrides Function DoInitialize() As Boolean
      If File.Exists(DBFileName) Then
         Dim bf As New BinaryFormatter()
         Dim f As FileStream = File.Open(DBFileName, FileMode.Open)
         DB = CType(bf.Deserialize(f), Dictionary(Of String, String))
         f.Close()
         Return True
      End If
      Return False
   End Function

   ''' <summary>
   ''' Serialisiert die im Arbeitsspeicher gehaltene 
   ''' <see cref="Dictionary(Of TKey, TValue)">Dictionary</see> in eine Datei.
   ''' </summary>
   ''' <remarks>Der Dateiname kann über den 
   ''' <see cref="BinaryDictionaryDB.New(String)">Konstruktor</see> oder die Eigenschaft
   ''' <see cref="DBFileName"/> festgelegt werden.<para/>
   ''' Die Serialisierung erfolgt im Binärformat (siehe <see cref="BinaryFormatter"/>).</remarks>
   Protected Overrides Sub DoPersist()
      Dim formatter As IFormatter = New BinaryFormatter()
      Dim stream As Stream = New FileStream(DBFileName, FileMode.Create, FileAccess.Write, FileShare.None)
      formatter.Serialize(stream, DB)
      stream.Close()
   End Sub
End Class
