﻿''' <summary>
''' Schnittstelle für einen Datenbank-Service
''' </summary>
Public Interface ITinyWebDB
   ''' <summary>Speichert einen Datenwert.</summary>
   ''' <param name="Key">Schlüsselwert, unter dem der Datenwert gespeichert werden soll.</param>
   ''' <param name="Data">Datenwert, der gespeichert werden soll.</param>
   ''' <remarks>Ist unter dem angegebenen Schlüssel bereits ein Wert abgelegt, wird 
   ''' er durch den angegebenen Wert ersetzt.</remarks>
   Sub StoreValue(Key As String, Data As String)

   ''' <summary>Ruf einen Datenwert aus der Datenbank ab.</summary>
   ''' <param name="Key">Der Schlüssel für den Datenwert.</param>
   ''' <returns>Der zum Schlüsselwert passende Datenwert oder <b>Nothing</b>, 
   ''' wenn unter dem Schlüssel kein Eintrag vorhanden ist.</returns>
   Function GetValue(Key As String) As String

   ''' <summary>Löscht den zum Schlüssel gehörenden Datenbankeintrag.</summary>
   ''' <param name="Key">Schlüsselwert des Datenbankeintrags, der gelöscht werden soll.</param>
   ''' <returns><b>True</b>, wenn der Schlüssel vorhanden war, ansonsten <b>false</b>.</returns>
   Function DeleteValue(Key As String) As Boolean

   ''' <summary>
   ''' Liefert den gesamten Datenbestand als Json-String.
   ''' </summary>
   ''' <returns>Der gesamte Datenbestand als Json-String.</returns>
   Function GetAll() As String

   ''' <summary>
   ''' Persisitiert im Arbeitsspeicher gehaltene Datenbanken / Datenbankeinträge.
   ''' </summary>
   Sub Persist()

   ''' <summary>
   ''' Inilialisiert die Datenbank. Ggf. werden Daten aus dem persisten Speicher in den
   ''' Arbeitsspeicher geladen.
   ''' </summary>
   ''' <returns><b>True</b>, wenn das Initialisieren erfolgreich war.</returns>
   Function Initialize() As Boolean

   ''' <summary>
   ''' Gibt an, ob Daten verändert wurden. Wenn <b>True</b> ist eine Persistierung notwendig.
   ''' </summary>
   ''' <returns><b>True</b>, wenn Daten verändert wurden.</returns>
   ReadOnly Property IsDirty As Boolean
End Interface
