﻿Imports System.IO
Imports Json.Net

''' <summary>
''' Implementierung einer Datenbank. Die Daten werden in einer
''' <see cref="Dictionary(Of TKey, TValue)">Dictionary</see> im Speicher gehalten.
''' </summary>
''' <remarks>Die Daten werden im Json-Format in einer Datei persisitiert.</remarks>
Public Class JsonDictionaryDB
   Inherits DictionaryDBBase

   ''' <summary>
   ''' Initalisiert eine neue Instanz der Datenbank.
   ''' </summary>
   ''' <param name="FileName">Der Dateipfad für die persistierten Daten.
   ''' Die Voreinstellung ist "UrsWebJsonDB.Json".</param>
   Public Sub New(Optional FileName As String = "UrsWebJsonDB.Json")
      MyBase.New(FileName)
   End Sub

   ''' <summary>
   ''' Liest den Datenbestand aus der festgelegten Datei ein.
   ''' </summary>
   ''' <returns><b>True</b>, wenn die Datei vorhanden ist.</returns>
   Protected Overrides Function DoInitialize() As Boolean
      If File.Exists(DBFileName) Then
         Dim JsonString = File.ReadAllText(DBFileName)
         DB = JsonNet.Deserialize(Of Dictionary(Of String, String))(JsonString)
         Return True
      Else
         Return False
      End If
   End Function

   ''' <summary>
   ''' Serialisiert die im Arbeitsspeicher gehaltene 
   ''' <see cref="Dictionary(Of TKey, TValue)">Dictionary</see> in eine Datei.
   ''' </summary>
   ''' <remarks>Der Dateiname kann über den 
   ''' <see cref="BinaryDictionaryDB.New(String)">Konstruktor</see> oder die Eigenschaft
   ''' <see cref="DBFileName"/> festgelegt werden.<para/>
   ''' Die Serialisierung erfolgt im Json-Format.</remarks>
   Protected Overrides Sub DoPersist()
      Dim JsonString As String
      JsonString = JsonNet.Serialize(DB)
      File.WriteAllText(DBFileName, JsonString)
   End Sub
End Class
